"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.migrateRegistry = exports.migrateIssuer = exports.migratePrivateIssuer = void 0;
const ethers_1 = require("ethers");
const const_1 = require("./const");
const contracts_1 = require("./contracts");
async function migratePrivateIssuer(provider, deployKey, issuerAddress) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const wallet = new ethers_1.ethers.Wallet(privateKeyDeployment, provider);
    const privateIssuerContract = await new contracts_1.factories.PrivateIssuerFactory(wallet).deploy();
    await privateIssuerContract.deployed();
    const tx = await privateIssuerContract.initialize(issuerAddress);
    await tx.wait();
    const version = await privateIssuerContract.version();
    console.log(`PrivateIssuer ${version} created at ${privateIssuerContract.address}`);
    return privateIssuerContract;
}
exports.migratePrivateIssuer = migratePrivateIssuer;
async function migrateIssuer(provider, deployKey, registryAddress) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const wallet = new ethers_1.ethers.Wallet(privateKeyDeployment, provider);
    const issuerContract = await new contracts_1.factories.IssuerFactory(wallet).deploy();
    await issuerContract.deployed();
    const tx = await issuerContract.initialize(const_1.CertificateTopic.IREC, registryAddress);
    await tx.wait();
    const version = await issuerContract.version();
    console.log(`Issuer ${version} created at ${issuerContract.address}`);
    return issuerContract;
}
exports.migrateIssuer = migrateIssuer;
async function migrateRegistry(provider, deployKey, uri = '') {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const wallet = new ethers_1.ethers.Wallet(privateKeyDeployment, provider);
    const registryContract = await new contracts_1.factories.RegistryExtendedFactory(wallet).deploy(uri);
    await registryContract.deployed();
    console.log(`RegistryExtended.sol deployed at ${registryContract.address}`);
    return registryContract;
}
exports.migrateRegistry = migrateRegistry;
//# sourceMappingURL=migrate.js.map